<?php

namespace App\Controllers;

use App\Models\UserModel;

class User extends BaseController
{

    private $userModel;

    public function __construct()
    {
        $this->userModel = new UserModel();
    }

    public function signup()
    {
        if (UserModel::checkAuth()) {
            return redirect('main.index');
        }

        if ($this->request->getMethod() == 'post') {
            if (!$this->userModel->insert($this->request->getPost())) {
                return redirect()->route('user.signup')->with('errors', $this->userModel->errors());
            } else {
                return redirect()->route('user.login')->with('success', 'Вы успешно зарегистрировались. Можно авторизоваться');
            }
        }
        return view('user/signup', ['title' => 'Регистрация']);
    }

    public function login()
    {
        if (UserModel::checkAuth()) {
            return redirect('main.index');
        }

        if ($this->request->getMethod() == 'post') {
            if (!$this->validate('userLogin')) {
                return redirect()->route('user.login')->with('errors', $this->validator->getErrors());
            }

            // Get user
            $user = $this->userModel->where('email', $this->request->getPost('email'))->first();

            // If !user OR !checkPassword
            if (!$user || !$this->userModel->checkPassword($this->request->getPost('password'), $user['password'])) {
                return redirect()->route('user.login')->with('fail', 'Incorrect email or password');
            }

            // If success validation AND login
            $this->userModel->setProfile($user);
            return redirect()->route('main.index');
        }
        return view('user/login', ['title' => 'Login']);
    }

    public function logout()
    {
        if (UserModel::checkAuth()) {
            session()->destroy();
        }
        return redirect('user.login');
    }

}
